#
# spec file for package perl-GDGraph
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name GDGraph
Name:           perl-GDGraph
Version:        1.560.0
Release:        1.5
# 1.56 -> normalize -> 1.560.0
%define cpan_version 1.56
#Upstream: Artistic-1.0 or GPL-1.0-or-later
License:        (Artistic-1.0 OR GPL-1.0-or-later) AND GPL-2.0-or-later
Summary:        Produces charts with GD
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BP/BPS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         perl-GDGraph-XBM-Magic.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.30
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(GD) >= 1.18
BuildRequires:  perl(GD::Text) >= 0.80
BuildRequires:  perl(Test::Exception) >= 0.40
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(GD) >= 1.18
Requires:       perl(GD::Text) >= 0.80
Provides:       perl(GD::Graph) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Produces charts with GD

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

# MANUAL BEGIN
perl -pi -e 's/\r\n/\n/' samples/sample64.pl
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES Dustismo.LICENSE Dustismo_Sans.ttf README samples

%changelog
* Fri Mar 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.56
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
  1.56 13 Jan 2023
  - Improve the language explaining the 2023 update. Docs-only change.
  1.55 11 Jan 2023
  - Fix failing XBM test resulting from some upstream changes
    Fixes: https://rt.cpan.org/Ticket/Display.html?id=140940
  - Skip samples tests if libgd has image support disabled, which
    is the default starting with version 2.3.3. See:
    https://github.com/libgd/libgd/issues/428
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 28 2022 Pedro Monreal <pmonreal@suse.com>
- Fix line endings in samples/sample64.pl
- Update the spec file with spec-cleaner
* Mon Feb 28 2022 Pedro Monreal <pmonreal@suse.com>
- Fix logo_xbm_noext test
  * Upstream PR: https://github.com/mgjv/GDGraph/pull/1
  * Add perl-GDGraph-XBM-Magic.patch
* Wed Apr  5 2017 mcaj@suse.com
- added perl-ExtUtils-MakeMaker to Build requires
  that fixed build for SLE-12-SP2 and openSUSE leap 42.x
* Wed Nov 23 2016 coolo@suse.com
- remove GDGraph-trim_miter.diff as still not upstream
* Wed Nov 23 2016 coolo@suse.com
- updated to 1.54
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
  1.54 21 Nov 2016
  - Disable two Y axes alignment when any y[12]_{min,max}_value is defined
    RT#62665
* Sat Jul  9 2016 coolo@suse.com
- updated to 1.53
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
  1.53 08 Jul 2016
  - Fix 'Illegal division by zero' when x_min_value and x_max_value
    are defined and x_tick_number set to 'auto' RT#73185
    Thanks to Bob Rogers, https://github.com/ruz/GDGraph/pull/12
* Sun Feb  7 2016 coolo@suse.com
- updated to 1.52
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
  1.52 28 Jan 2016
  - y1_min_range and y2_min_range instead of min_range_1 and min_range_2,
    niether were documented before.
  - Update documentation in regards to all *_min_range options available.
* Sat Jan  2 2016 coolo@suse.com
- updated to 1.51
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
* Sat May  2 2015 coolo@suse.com
- updated to 1.49
  see /usr/share/doc/packages/perl-GDGraph/CHANGES
  1.49
  - fix to Z-axis color filling in 3D pie charts (Debian Bug #489184)
  - bump ExtUtils::MakeMaker dependency
  - tiny improvement in the code of the samples
* Tue Oct  1 2013 darin@darins.net
- update to 1.48
  * no code changes, just release enginering cleanup
  * adjust MANIFEST.SKIP file so MANIFEST can be generated
    once again
  * ship sample58.pl file, so `make samples` stop failing
  * mention the current and past maintainers in META files
    as authors
  * use newer CPAN::Meta and ExtUtils::MakeMaker, older
    versions generated META files without runtime prerequisites
* Thu Apr 28 2011 vcizek@novell.com
- license correction (same as Perl)
- added new dependencies (bnc#676080)
- spec renewal
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Apr 26 2007 ro@suse.de
- update to 1.44
  - Added GD::Graph::hbars, to create horizontal bar charts.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Mar  3 2005 ro@suse.de
- added trim_miter patch from Juergen
* Tue Aug 24 2004 ro@suse.de
- updated neededforbuild (needing ImageMagick in testsuite)
* Wed Jul 28 2004 ro@suse.de
- update to 1.43
* Thu Sep 25 2003 ro@suse.de
- created package version 1.39
